pub struct LineScan {}Expand description
Scan a prepared image for QR Codes
The general idea of this method is as follows:
- Scan line by line horizontally for possible QR Finder patterns (the three squares)
- If a possible pattern is found, check vertically and diagonally to confirm it is indeed a pattern
- Try to find combinations of three patterns that are perpendicular and with similar distance that form a complete QR Code
Implementations