[−][src]Struct bardecoder::util::qr::QRData
QR Data extracted from the source image
While the data is still pixels of value 0/255, using the index will convert it into 1's (pixel 0) and 0's (pixel 255)
Example
use bardecoder::util::qr::QRData; let mut data = vec![0; 21 * 21]; data[21 * 21 - 1] = 255; let qr_data = QRData::new(data, 1); assert_eq!(qr_data.version, 1); assert_eq!(qr_data.side, 21); assert_eq!(qr_data[[0, 0]], 1); assert_eq!(qr_data[[20, 20]], 0);
Fields
data: Vec<u8>QR Pixel Data in side x side pixels, stored in row major order. Using the provided index will convert into 1's and 0's.
version: u32Version of the QR Code, 1 being the smallest, 40 the largest
side: u32Side in pixels of the QR square
Methods
impl QRData[src]
pub fn new(data: Vec<u8>, version: u32) -> QRData[src]
Create a new QRData object with the provided data and version. side will be calculated automatically.